Calculate the c-optimal design under the SLSE with the given combination of the parameters
Source:R/copt.R
copt.RdCalculate the c-optimal design under the SLSE with the given combination of the parameters
Arguments
- N
The number of sample points in the design space.
- u
The discretized design space.
- tt
The level of skewness. When tt=0, it is equivalent to compute the c-optimal design under the ordinary least squares estimator.
- FUN
The function to calculate the derivative of the given model.
- theta
The parameter value of the model.
- cVec
c vector used to determine the combination of the parameters
- show_cvxr_status
A boolean variable to indicate whether to show the status of the CVXR optimization. By default, it is set to FALSE.
Value
A list that contains 1. Value of the objective function at solution. 2. Status. 3. Optimal design
Details
This function calculates the c-optimal design and the loss function under the c-optimality. The loss function under c-optimality is defined as the log determinant of the inverse of the Fisher information matrix.